@@ -1,6 +1,7 @@
 from __future__ import with_statement
 
 import os
+from urllib2 import HTTPError
 
 from django.conf import settings
 from django.contrib.auth.models import AnonymousUser, User
@@ -114,6 +115,10 @@ class OAuthTwitterTest(TestCase):
         self.mocker.count(1, 2)
         Api(ANY).GetUserInfo()
         self.mocker.result(userinfo)
+        Api(ANY).GetUserInfo()
+        self.mocker.result(userinfo)
+        Api(ANY).GetUserInfo()
+        self.mocker.result(userinfo)
         with self.mocker:
             # User goes off to Twitter and gets redirected back to callback
             session = self.client.session
@@ -188,6 +193,22 @@ class OAuthTwitterTest(TestCase):
                           TwitterUser.objects.get, user=self.twitter)
 
 
+    def test_association_user_revoked(self):
+        # User visits associate after revoking their Twitter credentials.
+        self.assertTrue(self.twitter.twitter)
+        self.assertTrue(self.client.login(username=self.twitter.username,
+                                          password=self.twitter.username))
+        Api = self.mocker.replace(TwitterApi)
+        Api(ANY).GetUserInfo()
+        self.mocker.throw(HTTPError('url', 401, '', {}, None))
+        with self.mocker:
+            # User goes off to Twitter and gets redirected back to callback
+            session = self.client.session
+            session[REQUEST_KEY] = TOKEN.to_string()
+            session.save()
+            response = self.client.get(reverse(oauthtwitter.associate))
+            self.assertEqual(response.status_code, 200)
+
     def test_callback(self):
         # User goes directly to the callback page.
         response = self.client.get(reverse(oauthtwitter.callback))
