@@ -63,6 +63,15 @@ class OAuthTwitter(object):
         return urlpatterns
     urls = property(get_urls)
 
+    def unassociate(self, request):
+        user = request.user
+        try:
+            user.twitter.delete()
+            del user._twitter_cache
+            remove_tokens(request)
+        except TwitterUser.DoesNotExist:
+            pass
+
     def associate(self, request,
                   template="django_oauth_twitter/associate.html",
                   dictionary=None,
@@ -81,18 +90,20 @@ class OAuthTwitter(object):
                     try:
                         twitter_user = user.twitter
                         if twitter_user.twitter_id == twitter_id:
-                            twitter_user.delete()
-                        del user._twitter_cache
-                        remove_tokens(request)
+                            self.unassociate(request)
                         if post_remove is not None:
                             post_remove(request)
                     except TwitterUser.DoesNotExist:
                         pass
             else:
                 try:
-                    twitter_user = request.user.twitter
+                    twitter_user = user.twitter
                 except TwitterUser.DoesNotExist:
                     twitter_user = None
+                else:
+                    if twitter_user.is_revoked():
+                        self.unassociate(request)
+                        twitter_user = None
                 if request.GET.get('associated') and twitter_user is not None:
                     if post_associate is not None:
                         post_associate(request)
